# DataMarket scraping core

------------------------------------------------------
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


Utilities that integrate advance scraping knowledge into just one library.

## Installation

To install this library in your Python environment:

`pip install datamarket`

## Documentation

This library has built functionalities for the following topics:

- **Databases**: through sqlalchemy it allows to insert records and perform queries in any database.
- **Proxies**: wide range of functions to perform HTTP requests through custom proxies or the Tor network.
- **Tinybird**: a Python client for this popular API.
- **Drive**: functions to upload, delete or authenticate to Google Drive.
- **FTP**: functions to upload, delete or authenticate to an FTP, SFTP or FTPS server.
- **Selenium**: wrapper for the main Selenium functions.
